@@ -20,49 +20,49 @@ package org.apache.rat.analysis;
 
 import java.io.IOException;
 import java.io.Reader;
+import java.util.Collection;
 
 import org.apache.rat.api.Document;
-import org.apache.rat.document.IDocumentAnalyser;
-import org.apache.rat.document.RatDocumentAnalysisException;
+import org.apache.rat.document.DocumentAnalyser;
 import org.apache.rat.license.ILicense;
-import org.apache.rat.utils.Log;
+import org.apache.rat.utils.DefaultLog;
 
 import static java.lang.String.format;
 
 /**
  * A Document analyzer that analyses document headers for a license.
  */
-class DocumentHeaderAnalyser implements IDocumentAnalyser {
+class DocumentHeaderAnalyser implements DocumentAnalyser {
 
-    /**
-     * The license to analyse
-     */
-    private final ILicense license;
-    /** the logger to use */
-    private final Log log;
+    /** The license to analyse */
+    private final Collection<ILicense> licenses;
+    /** The matcher for generated headers */
+    private final IHeaderMatcher generatedMatcher;
 
     /**
      * Constructs the HeaderAnalyser for the specific license.
-     * 
-     * @param license The license to analyse
+     * @param licenses The licenses to analyse
      */
-    public DocumentHeaderAnalyser(final Log log, final ILicense license) {
+    DocumentHeaderAnalyser(final IHeaderMatcher generatedMatcher, final Collection<ILicense> licenses) {
         super();
-        this.license = license;
-        this.log = log;
+        this.generatedMatcher = generatedMatcher;
+        this.licenses = licenses;
     }
 
     @Override
-    public void analyse(Document document) throws RatDocumentAnalysisException {
-        try (Reader reader = document.reader()) {
-            log.debug(format("Processing: %s", document));
-            HeaderCheckWorker worker = new HeaderCheckWorker(reader, license, document);
-            worker.read();
-        } catch (IOException e) {
-            throw new RatDocumentAnalysisException("Cannot read header", e);
-        } catch (RatHeaderAnalysisException e) {
-            throw new RatDocumentAnalysisException("Cannot analyse header", e);
+    public void analyse(final Document document) {
+        if (!document.isIgnored()) {
+            try (Reader reader = document.reader()) {
+                DefaultLog.getInstance().debug(format("Processing: %s", document));
+                HeaderCheckWorker worker = new HeaderCheckWorker(generatedMatcher, reader, licenses, document);
+                worker.read();
+            } catch (IOException e) {
+                DefaultLog.getInstance().warn(String.format("Cannot read header of %s", document));
+                document.getMetaData().setDocumentType(Document.Type.UNKNOWN);
+            } catch (RatHeaderAnalysisException e) {
+                DefaultLog.getInstance().warn(String.format("Cannot process header of %s", document));
+                document.getMetaData().setDocumentType(Document.Type.UNKNOWN);
+            }
         }
     }
-
 }
