@@ -18,15 +18,18 @@
  */ 
 package org.apache.rat.analysis.license;
 
+import org.apache.rat.DeprecationReporter;
 import org.apache.rat.license.ILicenseFamily;
 
 @Deprecated // remove in v1.0
+@DeprecationReporter.Info(since = "0.16", forRemoval = true, use = "new configuration options")
 public abstract class BaseLicense implements DeprecatedConfig {
     private String licenseFamilyCategory;
     private String licenseFamilyName;
     private String notes;
 
     public BaseLicense() {
+        DeprecationReporter.logDeprecated(BaseLicense.class);
     }
 
     public String getLicenseFamilyCategory() {
@@ -54,10 +57,10 @@ public abstract class BaseLicense implements DeprecatedConfig {
     }
     
     @Override
-    final public ILicenseFamily getLicenseFamily() {
+    public final ILicenseFamily getLicenseFamily() {
         return ILicenseFamily.builder()
         .setLicenseFamilyCategory(licenseFamilyCategory)
         .setLicenseFamilyName(licenseFamilyName)
         .build();
     }
-}
\ No newline at end of file
+}
