@@ -18,16 +18,17 @@
  */
 package org.apache.rat.configuration.builders;
 
-import org.apache.rat.analysis.IHeaderMatcher;
 import org.apache.rat.analysis.matchers.AndMatcher;
+import org.apache.rat.config.parameters.MatcherBuilder;
 
 /**
- * Constructs a All matcher.
+ * Constructs an All matcher.
  */
+@MatcherBuilder(AndMatcher.class)
 public class AllBuilder extends ChildContainerBuilder {
 
     @Override
-    public IHeaderMatcher build() {
-        return new AndMatcher(getId(), getChildren());
+    public AndMatcher build() {
+        return new AndMatcher(getId(), getEnclosed(), resource);
     }
 }
