@@ -18,6 +18,10 @@
  */ 
 package org.apache.rat.header;
 
+import org.apache.rat.DeprecationReporter;
+
+@Deprecated // since 0.17
+@DeprecationReporter.Info(since = "0.17", forRemoval = true)
 interface CharFilter {
 
     /**
