@@ -15,21 +15,21 @@
  * KIND, either express or implied.  See the License for the    *
  * specific language governing permissions and limitations      *
  * under the License.                                           *
- */ 
+ */
 package org.apache.rat.report;
 
 import org.apache.rat.api.Document;
-import org.apache.rat.api.RatException;
-
 
 /**
  * Abstract base class for deriving implementations of {@link RatReport}.
+ * @deprecated use {@link RatReport} directly.
  */
+@Deprecated
 public abstract class AbstractReport implements RatReport {
     /**
      * Empty default implementation.
      */
-    public void startReport() throws RatException {
+    public void startReport() {
         // Does nothing
     }
 
@@ -37,14 +37,14 @@ public abstract class AbstractReport implements RatReport {
      * Empty default implementation.
      * @param document the actual document
      */
-    public void report(Document document) throws RatException {
+    public void report(final Document document) {
         // Does nothing
     }
 
     /**
      * Empty default implementation.
      */
-    public void endReport() throws RatException {
+    public void endReport() {
         // Does nothing
     }
 }
