@@ -19,52 +19,36 @@
 
 package org.apache.rat.walker;
 
+import org.apache.rat.api.Document;
+import org.apache.rat.document.DocumentName;
 import org.apache.rat.report.IReportable;
 
-import java.io.File;
-import java.io.FilenameFilter;
-import java.util.regex.Pattern;
-
 /**
  * Abstract walker.
  */
 public abstract class Walker implements IReportable {
 
-    protected final File file;
-    protected final String name;
+    /** The document this walker is walking */
+    private final Document document;
 
-    protected final FilenameFilter filter;
-
-    protected static FilenameFilter regexFilter(final Pattern pattern) {
-        return (dir, name) -> {
-            final boolean result;
-            if (pattern == null) {
-                result = true;
-            } else {
-                result = !pattern.matcher(name).matches();
-            }
-            return result;
-        };
-    }
- 
-    protected final boolean isNotIgnored(final File file) {
-        boolean result = false;
-        if (filter != null) {
-            final String name = file.getName();
-            final File dir = file.getParentFile();
-            result = !filter.accept(dir, name);
-        }
-        return !result;
+    /**
+     * Creates the walker
+     * @param document The document the walker is walking.
+     */
+    protected Walker(final Document document) {
+        this.document = document;
     }
 
-    public Walker(File file, final FilenameFilter filter) {
-        this(file.getPath(), file, filter);
+    /**
+     * Retrieves the document from the constructor.
+     * @return the document from the constructor.
+     */
+    protected Document getDocument() {
+        return document;
     }
 
-    protected Walker(final String name, final File file, final FilenameFilter filter) {
-        this.name = name;
-        this.file = file;
-        this.filter = filter;
+    @Override
+    public DocumentName getName() {
+        return document.getName();
     }
-
 }
