@@ -22,16 +22,20 @@ import javax.inject.Named;
 
 import org.apache.rat.configuration.builders.RegexBuilder;
 
+/**
+ *  @deprecated use Configuration file to define licenses
+ */
+@Deprecated
 public class Regex extends RegexBuilder {
 
     @Named("expr")
-    public RegexBuilder setExpr(String exp) {
-        System.out.format("Calling setText() with %s\n", exp);
-        return super.setExpr(exp);
+    public RegexBuilder setExpression(String expression) {
+        System.out.format("Calling setText() with %s\n", expression);
+        return super.setExpression(expression);
     }
     public void set(String exp) {
         System.out.format("Calling set() with %s\n", exp);
-        setExpr(exp);
+        setExpression(exp);
     }
 
 }
