@@ -18,13 +18,19 @@
  */
 package org.apache.rat.anttasks;
 
+import org.apache.rat.DeprecationReporter;
 import org.apache.rat.analysis.IHeaderMatcher;
-import org.apache.rat.analysis.IHeaderMatcher.Builder;
 import org.apache.rat.configuration.builders.AnyBuilder;
 
+/**
+ * Creates an Any matcher.
+ * @deprecated use configuration file.
+ */
+@Deprecated // since 0.17
+@DeprecationReporter.Info(since = "0.17", forRemoval = true, use = "Configuration file and <config> element")// since 0.17
 public class Any implements IHeaderMatcher.Builder {
 
-    private final AnyBuilder builder = Builder.any();
+    private final AnyBuilder builder = new AnyBuilder();
 
     @Override
     public IHeaderMatcher build() {
@@ -32,6 +38,6 @@ public class Any implements IHeaderMatcher.Builder {
     }
     
     public void add(IHeaderMatcher.Builder builder) {
-        this.builder.add(builder);
+        this.builder.addEnclosed(builder);
     }
 }
