@@ -18,23 +18,31 @@
  */
 package org.apache.rat.anttasks;
 
+import org.apache.rat.DeprecationReporter;
 import org.apache.rat.analysis.IHeaderMatcher;
+import org.apache.rat.analysis.matchers.SimpleRegexMatcher;
 import org.apache.rat.configuration.builders.RegexBuilder;
 
+/**
+ * Creates a Regex matcher.
+ * @deprecated use configuration file.
+ */
+@Deprecated // since 0.17
+@DeprecationReporter.Info(since = "0.17", forRemoval = true, use = "Configuration file and <config> element")// since 0.17
 public class Regex implements IHeaderMatcher.Builder {
 
     private final RegexBuilder builder = new RegexBuilder();
 
-    public void setRegex(String pattern) {
-        builder.setExpr(pattern);
+    public void setExpr(String pattern) {
+        builder.setExpression(pattern);
     }
-    
+
     public void addText(String pattern) {
-        builder.setExpr(pattern);
+        builder.setExpression(pattern);
     }
 
     @Override
-    public IHeaderMatcher build() {
+    public SimpleRegexMatcher build() {
         return builder.build();
     }
 }
